@@ -10,7 +10,7 @@ const Permutator = require('./Permutator');
 const NQuads = require('./NQuads');
 const util = require('./util');
 
-const POSITIONS = {'subject': 's', 'object': 'o', 'graph': 'g'};
+const POSITIONS = {subject: 's', object: 'o', graph: 'g'};
 
 module.exports = class URDNA2015 extends AsyncAlgorithm {
   constructor(options) {
@@ -186,7 +186,7 @@ module.exports = class URDNA2015 extends AsyncAlgorithm {
                 // in result, issue a canonical identifier, in the same order,
                 // using the Issue Identifier algorithm, passing canonical
                 // issuer and existing identifier.
-                for(let existing in result.issuer.existing) {
+                for(const existing in result.issuer.existing) {
                   self.canonicalIssuer.getId(existing);
                 }
                 callback();
@@ -483,7 +483,7 @@ module.exports = class URDNA2015 extends AsyncAlgorithm {
     ], err => {
       // 6) Return issuer and the hash that results from passing data to hash
       // through the hash algorithm.
-      callback(err, {hash: md.digest(), issuer: issuer});
+      callback(err, {hash: md.digest(), issuer});
     });
   }
 
@@ -552,7 +552,7 @@ module.exports = class URDNA2015 extends AsyncAlgorithm {
 
   // helper that iterates over quad components (skips predicate)
   forEachComponent(quad, op) {
-    for(let key in quad) {
+    for(const key in quad) {
       // skip `predicate`
       if(key === 'predicate') {
         continue;
